# 1 "read.mll"
 
  module Lexing =
    (*
      We override Lexing.engine in order to avoid creating a new position
      record each time a rule is matched.
      This reduces total parsing time by about 31%.
    *)
  struct
    include Lexing

    external c_engine : lex_tables -> int -> lexbuf -> int = "caml_lex_engine"

    let engine tbl state buf =
      let result = c_engine tbl state buf in
      (*
      if result >= 0 then begin
	buf.lex_start_p <- buf.lex_curr_p;
	buf.lex_curr_p <- {buf.lex_curr_p
			   with pos_cnum = buf.lex_abs_pos + buf.lex_curr_pos};
      end;
      *)
      result
  end

  open Printf
  open Lexing

  (* see description in common.mli *)
  type lexer_state = Lexer_state.t = {
    buf : Bi_outbuf.t;
    mutable lnum : int;
    mutable bol : int;
    mutable fname : string option;
  }

  let dec c =
    Char.code c - 48

  let hex c =
    match c with
	'0'..'9' -> int_of_char c - int_of_char '0'
      | 'a'..'f' -> int_of_char c - int_of_char 'a' + 10
      | 'A'..'F' -> int_of_char c - int_of_char 'A' + 10
      | _ -> assert false

  let custom_error descr v lexbuf =
    let offs = lexbuf.lex_abs_pos in
    let bol = v.bol in
    let pos1 = offs + lexbuf.lex_start_pos - bol in
    let pos2 = max pos1 (offs + lexbuf.lex_curr_pos - bol - 1) in
    let file_line =
      match v.fname with
	  None -> "Line"
	| Some s ->
	    sprintf "File %s, line" s
    in
    let bytes =
      if pos1 = pos2 then
	sprintf "byte %i" (pos1+1)
      else
	sprintf "bytes %i-%i" (pos1+1) (pos2+1)
    in
    let msg = sprintf "%s %i, %s:\n%s" file_line v.lnum bytes descr in
    json_error msg


  let lexer_error descr v lexbuf =
    custom_error 
      (sprintf "%s '%s'" descr (Lexing.lexeme lexbuf))
      v lexbuf

  let read_junk = ref (fun _ -> assert false)

  let long_error descr v lexbuf =
    let junk = Lexing.lexeme lexbuf in
    let extra_junk = !read_junk lexbuf in
    custom_error 
      (sprintf "%s '%s%s'" descr junk extra_junk)
      v lexbuf

  let min10 = min_int / 10 - (if min_int mod 10 = 0 then 0 else 1)
  let max10 = max_int / 10 + (if max_int mod 10 = 0 then 0 else 1)

  exception Int_overflow

  let extract_positive_int lexbuf =
    let start = lexbuf.lex_start_pos in
    let stop = lexbuf.lex_curr_pos in
    let s = lexbuf.lex_buffer in
    let n = ref 0 in
    for i = start to stop - 1 do
      if !n >= max10 then
	raise Int_overflow
      else
	n := 10 * !n + dec s.[i]
    done;
    if !n < 0 then
      raise Int_overflow
    else
      !n

  let make_positive_int v lexbuf =
    #ifdef INT
      try `Int (extract_positive_int lexbuf)
      with Int_overflow ->
    #endif
      #ifdef INTLIT
	`Intlit (lexeme lexbuf)
      #else
        lexer_error "Int overflow" v lexbuf
      #endif

  let extract_negative_int lexbuf =
    let start = lexbuf.lex_start_pos + 1 in
    let stop = lexbuf.lex_curr_pos in
    let s = lexbuf.lex_buffer in
    let n = ref 0 in
    for i = start to stop - 1 do
      if !n <= min10 then
	raise Int_overflow
      else
	n := 10 * !n - dec s.[i]
    done;
    if !n > 0 then
      raise Int_overflow
    else
      !n

  let make_negative_int v lexbuf =
    #ifdef INT
      try `Int (extract_negative_int lexbuf)
      with Int_overflow ->
    #endif
      #ifdef INTLIT
	`Intlit (lexeme lexbuf)
      #else
        lexer_error "Int overflow" v lexbuf
      #endif


  let set_file_name v fname =
    v.fname <- fname

  let newline v lexbuf =
    v.lnum <- v.lnum + 1;
    v.bol <- lexbuf.lex_abs_pos + lexbuf.lex_curr_pos

  let add_lexeme buf lexbuf =
    let len = lexbuf.lex_curr_pos - lexbuf.lex_start_pos in
    Bi_outbuf.add_substring buf lexbuf.lex_buffer lexbuf.lex_start_pos len

  let map_lexeme f lexbuf =
    let len = lexbuf.lex_curr_pos - lexbuf.lex_start_pos in
    f lexbuf.lex_buffer lexbuf.lex_start_pos len

  type variant_kind = [ `Edgy_bracket | `Square_bracket | `Double_quote ]
  type tuple_kind = [ `Parenthesis | `Square_bracket ]

# 161 "read.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\236\255\237\255\003\000\239\255\016\000\242\255\243\255\
    \244\255\245\255\000\000\031\000\249\255\085\000\001\000\000\000\
    \000\000\001\000\000\000\001\000\002\000\255\255\000\000\000\000\
    \003\000\254\255\001\000\004\000\253\255\011\000\252\255\003\000\
    \001\000\003\000\002\000\003\000\000\000\251\255\021\000\097\000\
    \010\000\022\000\020\000\016\000\022\000\012\000\008\000\250\255\
    \119\000\129\000\139\000\161\000\171\000\181\000\193\000\209\000\
    \240\255\011\000\038\000\252\255\065\000\254\255\255\255\110\000\
    \252\255\163\000\254\255\255\255\234\000\247\255\248\255\048\001\
    \250\255\251\255\252\255\253\255\254\255\255\255\071\001\126\001\
    \149\001\249\255\220\000\253\255\255\255\235\000\174\001\244\001\
    \236\000\223\001\043\002\066\002\104\002\034\000\252\255\253\255\
    \254\255\255\255\015\000\253\255\254\255\255\255\031\000\253\255\
    \254\255\255\255\017\000\253\255\254\255\255\255\238\000\251\255\
    \252\255\253\255\254\255\255\255\020\000\252\255\253\255\254\255\
    \012\000\255\255\018\000\255\255\013\001\005\000\253\255\023\000\
    \254\255\019\000\255\255\021\000\253\255\254\255\038\000\048\000\
    \051\000\255\255\050\000\044\000\055\000\057\000\255\255\184\000\
    \252\255\253\255\102\000\086\000\084\000\102\000\255\255\097\000\
    \092\000\138\000\254\255\254\000\251\255\252\255\253\255\103\001\
    \255\255\127\002\254\255\137\002\162\002\252\255\253\255\254\255\
    \255\255\172\002\182\002\206\002\252\255\253\255\254\255\255\255\
    \193\002\216\002\240\002\249\255\250\255\251\255\245\000\252\002\
    \018\003\141\000\155\000\016\000\255\255\151\000\175\000\173\000\
    \179\000\169\000\168\000\254\255\182\000\191\000\190\000\186\000\
    \192\000\197\000\194\000\253\255\033\003\227\002\050\003\072\003\
    \082\003\092\003\104\003\115\003\061\000\253\255\254\255\255\255\
    \144\003\252\255\253\255\219\003\255\255\021\004\252\255\253\255\
    \097\004\255\255\229\000\253\255\254\255\255\255\231\000\253\255\
    \254\255\255\255\225\000\255\255\019\001\252\255\253\255\254\255\
    \255\255\027\001\253\255\254\255\255\255\000\000\255\255\036\001\
    \254\255\255\255\067\001\252\255\253\255\254\255\255\255\146\001\
    \251\255\252\255\253\255\254\255\255\255\207\000\253\255\254\255\
    \255\255\211\000\253\255\254\255\255\255\199\000\255\255\063\001\
    \252\255\253\255\254\255\255\255\011\001\253\255\254\255\255\255\
    \051\001\252\255\253\255\254\255\255\255\046\001\253\255\254\255\
    \255\255\048\001\253\255\254\255\255\255\240\000\253\255\254\255\
    \255\255\242\000\253\255\254\255\255\255\211\004\237\255\238\255\
    \006\000\240\255\024\000\243\255\244\255\245\255\246\255\063\001\
    \134\003\249\255\177\004\227\000\241\000\222\000\243\000\227\000\
    \226\000\248\000\255\255\254\000\015\001\030\001\254\255\025\001\
    \026\001\253\255\057\001\252\255\041\001\039\001\051\001\057\001\
    \049\001\045\001\251\255\057\001\083\001\081\001\079\001\104\001\
    \094\001\091\001\250\255\242\004\144\003\255\004\031\005\041\005\
    \053\005\063\005\073\005\241\255\252\001\116\002\253\255\255\255\
    \021\003\098\005\085\005\022\003\115\005\185\005\208\005\246\005\
    \197\001\252\255\253\255\254\255\255\255\028\006\252\255\253\255\
    \103\006\255\255\213\000\222\000\230\000\255\255\232\000\233\000\
    \237\000\241\000\243\000\244\000\245\000\252\000\253\000\000\001\
    \002\001\004\001\005\001\007\001\008\001\009\001\012\001\013\001\
    \015\001\017\001\018\001\021\001\022\001\023\001\024\001\025\001\
    \026\001\029\001\030\001\000\000";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\017\000\255\255\019\000\255\255\255\255\
    \255\255\255\255\007\000\007\000\255\255\019\000\019\000\019\000\
    \019\000\019\000\019\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\008\000\008\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\009\000\255\255\009\000\255\255\009\000\255\255\
    \255\255\014\000\255\255\255\255\002\000\255\255\255\255\255\255\
    \255\255\002\000\255\255\255\255\255\255\255\255\255\255\007\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\001\000\001\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \003\000\255\255\001\000\255\255\004\000\003\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\001\000\255\255\
    \255\255\255\255\001\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\002\000\002\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\003\000\
    \255\255\000\000\255\255\001\000\255\255\255\255\255\255\255\255\
    \255\255\000\000\002\000\255\255\255\255\255\255\255\255\255\255\
    \000\000\002\000\255\255\255\255\255\255\255\255\003\000\003\000\
    \005\000\005\000\005\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\003\000\255\255\
    \003\000\255\255\003\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\001\000\255\255\255\255\255\255\255\255\
    \001\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\001\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\001\000\255\255\002\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\001\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \016\000\255\255\018\000\255\255\255\255\255\255\255\255\007\000\
    \007\000\255\255\018\000\018\000\018\000\018\000\018\000\018\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\008\000\255\255\008\000\
    \255\255\008\000\255\255\255\255\013\000\255\255\255\255\255\255\
    \001\000\001\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \001\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255";
  Lexing.lex_default = 
   "\001\000\000\000\000\000\255\255\000\000\255\255\000\000\000\000\
    \000\000\000\000\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\000\000\255\255\255\255\000\000\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\057\000\060\000\000\000\060\000\000\000\000\000\065\000\
    \000\000\065\000\000\000\000\000\070\000\000\000\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\000\000\085\000\000\000\000\000\088\000\255\255\255\255\
    \088\000\255\255\255\255\255\255\255\255\095\000\000\000\000\000\
    \000\000\000\000\100\000\000\000\000\000\000\000\104\000\000\000\
    \000\000\000\000\108\000\000\000\000\000\000\000\112\000\000\000\
    \000\000\000\000\000\000\000\000\117\000\000\000\000\000\000\000\
    \255\255\000\000\255\255\000\000\255\255\255\255\000\000\255\255\
    \000\000\129\000\000\000\133\000\000\000\000\000\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\000\000\145\000\
    \000\000\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\000\000\157\000\000\000\000\000\000\000\255\255\
    \000\000\255\255\000\000\255\255\166\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\173\000\000\000\000\000\000\000\000\000\
    \255\255\255\255\180\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\214\000\000\000\000\000\000\000\
    \218\000\000\000\000\000\255\255\000\000\223\000\000\000\000\000\
    \255\255\000\000\228\000\000\000\000\000\000\000\232\000\000\000\
    \000\000\000\000\255\255\000\000\238\000\000\000\000\000\000\000\
    \000\000\243\000\000\000\000\000\000\000\255\255\000\000\255\255\
    \000\000\000\000\252\000\000\000\000\000\000\000\000\000\001\001\
    \000\000\000\000\000\000\000\000\000\000\007\001\000\000\000\000\
    \000\000\011\001\000\000\000\000\000\000\255\255\000\000\017\001\
    \000\000\000\000\000\000\000\000\022\001\000\000\000\000\000\000\
    \026\001\000\000\000\000\000\000\000\000\031\001\000\000\000\000\
    \000\000\035\001\000\000\000\000\000\000\039\001\000\000\000\000\
    \000\000\043\001\000\000\000\000\000\000\046\001\000\000\000\000\
    \255\255\000\000\255\255\000\000\000\000\000\000\000\000\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\000\000\255\255\
    \255\255\000\000\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\100\001\104\001\000\000\000\000\
    \107\001\255\255\255\255\107\001\255\255\255\255\255\255\255\255\
    \114\001\000\000\000\000\000\000\000\000\119\001\000\000\000\000\
    \255\255\000\000\123\001\124\001\126\001\000\000\127\001\128\001\
    \129\001\130\001\131\001\132\001\133\001\134\001\135\001\136\001\
    \137\001\138\001\139\001\140\001\141\001\142\001\143\001\144\001\
    \145\001\146\001\147\001\148\001\149\001\150\001\151\001\152\001\
    \153\001\154\001\155\001\125\001";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\003\000\004\000\000\000\003\000\003\000\125\000\048\001\
    \003\000\000\000\125\000\048\001\000\000\255\255\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\130\000\118\000\000\000\
    \003\000\000\000\012\000\003\000\000\000\125\000\048\001\000\000\
    \007\000\246\000\000\000\000\000\000\000\013\000\049\000\005\000\
    \010\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\056\000\121\000\006\000\109\000\120\000\057\000\
    \000\000\128\000\099\001\049\000\000\000\048\000\129\000\100\001\
    \062\000\014\000\000\000\101\000\000\000\049\000\015\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\030\000\048\000\008\000\097\000\105\000\188\000\215\000\
    \096\000\029\000\022\000\255\255\048\000\048\000\017\000\021\000\
    \025\000\032\000\033\000\035\000\023\000\027\000\016\000\031\000\
    \028\000\034\000\019\000\024\000\018\000\026\000\020\000\036\000\
    \041\000\037\000\048\000\009\000\042\000\043\000\044\000\045\000\
    \046\000\047\000\061\000\134\000\048\000\038\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\049\000\
    \067\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\135\000\136\000\255\255\040\000\137\000\
    \139\000\140\000\055\000\141\000\055\000\142\000\048\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\255\255\048\000\151\000\
    \148\000\149\000\066\000\150\000\053\000\152\000\053\000\153\000\
    \051\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\154\000\
    \051\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\189\000\187\000\190\000\084\000\255\255\
    \002\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\255\255\077\000\084\000\084\000\099\000\
    \114\000\107\000\123\000\130\000\119\000\132\000\125\000\126\000\
    \191\000\077\000\125\000\192\000\193\000\194\000\146\000\103\000\
    \158\000\195\000\094\000\205\000\197\000\198\000\059\000\199\000\
    \200\000\201\000\115\000\159\000\147\000\125\000\160\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \086\000\202\000\204\000\203\000\127\000\213\000\235\000\240\000\
    \229\000\255\255\233\000\244\000\014\001\023\001\077\000\089\000\
    \089\000\113\000\008\001\040\001\076\000\249\000\012\001\044\001\
    \075\000\076\001\074\001\071\001\067\001\064\001\032\001\065\001\
    \074\000\036\001\204\000\028\001\073\000\066\001\072\000\071\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\068\001\019\001\253\000\092\001\064\000\254\000\
    \239\000\078\000\078\000\078\000\078\000\078\000\078\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\248\000\069\001\070\001\091\001\072\001\073\001\075\001\
    \079\000\079\000\079\000\079\000\079\000\079\000\027\001\077\001\
    \078\001\078\000\078\000\078\000\078\000\078\000\078\000\162\000\
    \163\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\079\001\080\001\255\255\091\001\081\001\082\001\084\001\
    \079\000\079\000\079\000\079\000\079\000\079\000\080\000\080\000\
    \080\000\080\000\080\000\080\000\080\000\080\000\080\000\080\000\
    \144\000\085\001\086\001\003\001\018\001\087\001\004\001\080\000\
    \080\000\080\000\080\000\080\000\080\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\081\000\081\000\081\000\006\001\
    \088\000\088\001\089\001\010\001\090\001\255\255\081\000\081\000\
    \081\000\081\000\081\000\081\000\083\000\088\000\125\001\080\000\
    \080\000\080\000\080\000\080\000\080\000\227\000\125\001\231\000\
    \125\001\125\001\069\000\255\255\255\255\125\001\111\000\002\001\
    \038\001\125\001\042\001\125\001\125\001\125\001\081\000\081\000\
    \081\000\081\000\081\000\081\000\125\001\125\001\156\000\116\001\
    \125\001\088\000\125\001\115\001\125\001\125\001\255\255\125\001\
    \125\001\125\001\088\000\021\001\125\001\125\001\088\000\125\001\
    \088\000\125\001\125\001\237\000\088\000\125\001\125\001\125\001\
    \125\001\125\001\125\001\242\000\088\000\125\001\125\001\000\000\
    \088\000\000\000\088\000\087\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\030\001\000\000\
    \034\001\000\000\000\000\025\001\000\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\088\000\000\000\000\000\000\000\016\001\
    \000\000\088\000\000\000\251\000\000\000\088\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\088\000\000\000\000\000\
    \000\000\088\000\000\000\088\000\087\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\091\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\091\000\091\000\091\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\092\000\092\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\000\000\000\000\000\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\000\001\000\000\000\000\000\000\103\001\000\000\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\000\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\088\000\088\000\088\000\088\000\088\000\088\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\000\000\167\000\113\001\000\000\000\000\
    \000\000\088\000\088\000\088\000\088\000\088\000\088\000\170\000\
    \105\001\000\000\168\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\168\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\169\000\169\000\
    \174\000\176\000\176\000\176\000\176\000\176\000\176\000\176\000\
    \176\000\176\000\176\000\177\000\255\255\000\000\175\000\176\000\
    \176\000\176\000\176\000\176\000\176\000\176\000\176\000\176\000\
    \175\000\176\000\176\000\176\000\176\000\176\000\176\000\176\000\
    \176\000\176\000\181\000\206\000\206\000\206\000\206\000\206\000\
    \206\000\206\000\206\000\206\000\206\000\184\000\000\000\000\000\
    \182\000\183\000\183\000\183\000\183\000\183\000\183\000\183\000\
    \183\000\183\000\205\000\000\000\183\000\183\000\183\000\183\000\
    \183\000\183\000\183\000\183\000\183\000\183\000\000\000\103\001\
    \103\001\185\000\000\000\000\000\000\000\000\000\186\000\000\000\
    \000\000\204\000\182\000\183\000\183\000\183\000\183\000\183\000\
    \183\000\183\000\183\000\183\000\211\000\000\000\211\000\000\000\
    \000\000\210\000\210\000\210\000\210\000\210\000\210\000\210\000\
    \210\000\210\000\210\000\196\000\000\000\000\000\000\000\000\000\
    \000\000\204\000\206\000\206\000\206\000\206\000\206\000\206\000\
    \206\000\206\000\206\000\206\000\000\000\000\000\000\000\000\000\
    \000\000\108\001\108\001\209\000\102\001\209\000\000\000\207\000\
    \208\000\208\000\208\000\208\000\208\000\208\000\208\000\208\000\
    \208\000\208\000\208\000\208\000\208\000\208\000\208\000\208\000\
    \208\000\208\000\208\000\208\000\208\000\208\000\208\000\208\000\
    \208\000\208\000\208\000\208\000\208\000\208\000\000\000\207\000\
    \210\000\210\000\210\000\210\000\210\000\210\000\210\000\210\000\
    \210\000\210\000\165\000\210\000\210\000\210\000\210\000\210\000\
    \210\000\210\000\210\000\210\000\210\000\000\000\000\000\000\000\
    \000\000\000\000\220\000\000\000\092\001\000\000\056\001\056\001\
    \056\001\056\001\056\001\056\001\056\001\056\001\056\001\056\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\093\001\000\000\091\001\000\000\000\000\172\000\000\000\
    \000\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\091\001\000\000\000\000\000\000\219\000\
    \179\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\255\255\255\255\000\000\
    \000\000\000\000\000\000\000\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\000\000\225\000\
    \000\000\000\000\219\000\000\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \000\000\000\000\000\000\000\000\224\000\000\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \217\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\000\000\000\000\000\000\000\000\
    \224\000\000\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\048\001\049\001\000\000\000\000\
    \048\001\055\001\056\001\056\001\056\001\056\001\056\001\056\001\
    \056\001\056\001\056\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\048\001\000\000\057\001\000\000\000\000\
    \000\000\000\000\083\001\052\001\000\000\000\000\000\000\000\000\
    \058\001\000\000\050\001\055\001\056\001\056\001\056\001\056\001\
    \056\001\056\001\056\001\056\001\056\001\000\000\000\000\051\001\
    \000\000\000\000\000\000\000\000\000\000\222\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\059\001\098\001\000\000\098\001\
    \000\000\060\001\097\001\097\001\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\097\001\000\000\000\000\053\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\062\001\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\061\001\000\000\000\000\094\001\000\000\000\000\063\001\
    \000\000\000\000\096\001\000\000\096\001\000\000\054\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\000\000\094\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\095\001\095\001\095\001\095\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
    \097\001\097\001\097\001\000\000\107\001\109\001\109\001\109\001\
    \109\001\109\001\109\001\109\001\109\001\109\001\109\001\000\000\
    \000\000\107\001\000\000\000\000\000\000\107\001\109\001\109\001\
    \109\001\109\001\109\001\109\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\107\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\109\001\109\001\
    \109\001\109\001\109\001\109\001\000\000\000\000\107\001\000\000\
    \000\000\000\000\000\000\000\000\107\001\000\000\000\000\000\000\
    \107\001\000\000\000\000\000\000\000\000\000\000\000\000\107\001\
    \107\001\000\000\000\000\047\001\107\001\107\001\107\001\106\001\
    \000\000\107\001\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\107\001\000\000\000\000\000\000\107\001\000\000\107\001\
    \106\001\110\001\110\001\110\001\110\001\110\001\110\001\110\001\
    \110\001\110\001\110\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\110\001\110\001\110\001\110\001\110\001\110\001\
    \111\001\111\001\111\001\111\001\111\001\111\001\111\001\111\001\
    \111\001\111\001\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\111\001\111\001\111\001\111\001\111\001\111\001\000\000\
    \000\000\000\000\110\001\110\001\110\001\110\001\110\001\110\001\
    \000\000\000\000\000\000\000\000\000\000\000\000\107\001\107\001\
    \107\001\107\001\107\001\107\001\107\001\107\001\107\001\107\001\
    \000\000\111\001\111\001\111\001\111\001\111\001\111\001\107\001\
    \107\001\107\001\107\001\107\001\107\001\000\000\121\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\107\001\
    \107\001\107\001\107\001\107\001\107\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\000\000\
    \000\000\000\000\000\000\120\001\000\000\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\000\000\000\000\000\000\000\000\120\001\000\000\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\118\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    ";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\003\000\000\000\125\000\048\001\
    \003\000\255\255\125\000\048\001\255\255\057\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\129\000\116\000\255\255\
    \000\000\255\255\000\000\003\000\255\255\125\000\048\001\255\255\
    \000\000\245\000\255\255\255\255\255\255\000\000\010\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\005\000\120\000\000\000\106\000\116\000\005\000\
    \255\255\127\000\050\001\038\000\255\255\010\000\127\000\050\001\
    \058\000\000\000\255\255\098\000\255\255\011\000\000\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\029\000\038\000\000\000\093\000\102\000\187\000\212\000\
    \093\000\015\000\017\000\060\000\011\000\010\000\000\000\020\000\
    \024\000\031\000\032\000\034\000\022\000\026\000\000\000\014\000\
    \027\000\033\000\018\000\023\000\000\000\016\000\019\000\035\000\
    \040\000\036\000\038\000\000\000\041\000\042\000\043\000\044\000\
    \045\000\046\000\058\000\131\000\011\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\039\000\
    \063\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\134\000\135\000\060\000\013\000\136\000\
    \138\000\139\000\048\000\140\000\048\000\141\000\039\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\065\000\039\000\146\000\
    \147\000\148\000\063\000\149\000\051\000\151\000\051\000\152\000\
    \050\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\153\000\
    \050\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\185\000\186\000\189\000\082\000\065\000\
    \000\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\057\000\068\000\085\000\088\000\098\000\
    \110\000\106\000\122\000\129\000\116\000\131\000\124\000\124\000\
    \190\000\068\000\124\000\191\000\192\000\193\000\143\000\102\000\
    \155\000\194\000\093\000\182\000\196\000\197\000\058\000\198\000\
    \199\000\200\000\110\000\155\000\143\000\124\000\155\000\155\000\
    \155\000\155\000\155\000\155\000\155\000\155\000\155\000\155\000\
    \082\000\201\000\182\000\202\000\124\000\212\000\234\000\236\000\
    \226\000\060\000\230\000\241\000\013\001\020\001\068\000\085\000\
    \088\000\110\000\005\001\037\001\068\000\247\000\009\001\041\001\
    \068\000\059\001\060\001\061\001\062\001\063\001\029\001\064\001\
    \068\000\033\001\182\000\024\001\068\000\065\001\068\000\068\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\067\001\015\001\250\000\055\001\063\000\250\000\
    \236\000\071\000\071\000\071\000\071\000\071\000\071\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\247\000\068\001\069\001\055\001\071\001\072\001\074\001\
    \078\000\078\000\078\000\078\000\078\000\078\000\024\001\076\001\
    \077\001\071\000\071\000\071\000\071\000\071\000\071\000\159\000\
    \159\000\159\000\159\000\159\000\159\000\159\000\159\000\159\000\
    \159\000\078\001\079\001\065\000\055\001\080\001\081\001\083\001\
    \078\000\078\000\078\000\078\000\078\000\078\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \143\000\084\001\085\001\255\000\015\001\086\001\255\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\080\000\080\000\080\000\
    \080\000\080\000\080\000\080\000\080\000\080\000\080\000\005\001\
    \086\000\087\001\088\001\009\001\089\001\122\001\080\000\080\000\
    \080\000\080\000\080\000\080\000\082\000\086\000\123\001\079\000\
    \079\000\079\000\079\000\079\000\079\000\226\000\124\001\230\000\
    \126\001\127\001\068\000\085\000\088\000\128\001\110\000\255\000\
    \037\001\129\001\041\001\130\001\131\001\132\001\080\000\080\000\
    \080\000\080\000\080\000\080\000\133\001\134\001\155\000\112\001\
    \135\001\089\000\136\001\112\001\137\001\138\001\100\001\139\001\
    \140\001\141\001\086\000\020\001\142\001\143\001\089\000\144\001\
    \086\000\145\001\146\001\236\000\086\000\147\001\148\001\149\001\
    \150\001\151\001\152\001\241\000\086\000\153\001\154\001\255\255\
    \086\000\255\255\086\000\086\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\087\000\029\001\255\255\
    \033\001\255\255\255\255\024\001\255\255\087\000\087\000\087\000\
    \087\000\087\000\087\000\089\000\255\255\255\255\255\255\015\001\
    \255\255\089\000\255\255\250\000\255\255\089\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\089\000\255\255\255\255\
    \255\255\089\000\255\255\089\000\089\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\090\000\090\000\090\000\090\000\
    \090\000\090\000\091\000\091\000\091\000\091\000\091\000\091\000\
    \091\000\091\000\091\000\091\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\091\000\091\000\091\000\091\000\091\000\
    \091\000\255\255\255\255\255\255\090\000\090\000\090\000\090\000\
    \090\000\090\000\255\000\255\255\255\255\255\255\101\001\255\255\
    \092\000\092\000\092\000\092\000\092\000\092\000\092\000\092\000\
    \092\000\092\000\255\255\091\000\091\000\091\000\091\000\091\000\
    \091\000\092\000\092\000\092\000\092\000\092\000\092\000\161\000\
    \161\000\161\000\161\000\161\000\161\000\161\000\161\000\161\000\
    \161\000\163\000\163\000\163\000\163\000\163\000\163\000\163\000\
    \163\000\163\000\163\000\255\255\164\000\112\001\255\255\255\255\
    \255\255\092\000\092\000\092\000\092\000\092\000\092\000\164\000\
    \101\001\255\255\164\000\164\000\164\000\164\000\164\000\164\000\
    \164\000\164\000\164\000\164\000\169\000\169\000\169\000\169\000\
    \169\000\169\000\169\000\169\000\169\000\169\000\170\000\170\000\
    \170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\
    \171\000\176\000\176\000\176\000\176\000\176\000\176\000\176\000\
    \176\000\176\000\176\000\171\000\100\001\255\255\171\000\171\000\
    \171\000\171\000\171\000\171\000\171\000\171\000\171\000\171\000\
    \177\000\177\000\177\000\177\000\177\000\177\000\177\000\177\000\
    \177\000\177\000\178\000\205\000\205\000\205\000\205\000\205\000\
    \205\000\205\000\205\000\205\000\205\000\178\000\255\255\255\255\
    \178\000\178\000\178\000\178\000\178\000\178\000\178\000\178\000\
    \178\000\178\000\183\000\255\255\183\000\183\000\183\000\183\000\
    \183\000\183\000\183\000\183\000\183\000\183\000\255\255\104\001\
    \107\001\178\000\255\255\255\255\255\255\255\255\178\000\255\255\
    \255\255\183\000\184\000\184\000\184\000\184\000\184\000\184\000\
    \184\000\184\000\184\000\184\000\204\000\255\255\204\000\255\255\
    \255\255\204\000\204\000\204\000\204\000\204\000\204\000\204\000\
    \204\000\204\000\204\000\184\000\255\255\255\255\255\255\255\255\
    \255\255\183\000\206\000\206\000\206\000\206\000\206\000\206\000\
    \206\000\206\000\206\000\206\000\255\255\255\255\255\255\255\255\
    \255\255\104\001\107\001\207\000\101\001\207\000\255\255\206\000\
    \207\000\207\000\207\000\207\000\207\000\207\000\207\000\207\000\
    \207\000\207\000\208\000\208\000\208\000\208\000\208\000\208\000\
    \208\000\208\000\208\000\208\000\209\000\209\000\209\000\209\000\
    \209\000\209\000\209\000\209\000\209\000\209\000\255\255\206\000\
    \210\000\210\000\210\000\210\000\210\000\210\000\210\000\210\000\
    \210\000\210\000\164\000\211\000\211\000\211\000\211\000\211\000\
    \211\000\211\000\211\000\211\000\211\000\255\255\255\255\255\255\
    \255\255\255\255\216\000\255\255\056\001\255\255\056\001\056\001\
    \056\001\056\001\056\001\056\001\056\001\056\001\056\001\056\001\
    \092\001\092\001\092\001\092\001\092\001\092\001\092\001\092\001\
    \092\001\092\001\255\255\056\001\255\255\255\255\171\000\255\255\
    \255\255\216\000\216\000\216\000\216\000\216\000\216\000\216\000\
    \216\000\216\000\216\000\216\000\216\000\216\000\216\000\216\000\
    \216\000\216\000\216\000\216\000\216\000\216\000\216\000\216\000\
    \216\000\216\000\216\000\056\001\255\255\255\255\255\255\216\000\
    \178\000\216\000\216\000\216\000\216\000\216\000\216\000\216\000\
    \216\000\216\000\216\000\216\000\216\000\216\000\216\000\216\000\
    \216\000\216\000\216\000\216\000\216\000\216\000\216\000\216\000\
    \216\000\216\000\216\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\104\001\107\001\255\255\
    \255\255\255\255\255\255\255\255\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\255\255\221\000\
    \255\255\255\255\219\000\255\255\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\221\000\221\000\
    \221\000\221\000\221\000\221\000\221\000\221\000\221\000\221\000\
    \221\000\221\000\221\000\221\000\221\000\221\000\221\000\221\000\
    \221\000\221\000\221\000\221\000\221\000\221\000\221\000\221\000\
    \255\255\255\255\255\255\255\255\221\000\255\255\221\000\221\000\
    \221\000\221\000\221\000\221\000\221\000\221\000\221\000\221\000\
    \221\000\221\000\221\000\221\000\221\000\221\000\221\000\221\000\
    \221\000\221\000\221\000\221\000\221\000\221\000\221\000\221\000\
    \216\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\255\255\255\255\255\255\255\255\
    \224\000\255\255\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\224\000\224\000\224\000\224\000\
    \224\000\224\000\224\000\224\000\045\001\045\001\255\255\255\255\
    \045\001\058\001\058\001\058\001\058\001\058\001\058\001\058\001\
    \058\001\058\001\058\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\045\001\255\255\045\001\255\255\255\255\
    \255\255\255\255\058\001\045\001\255\255\255\255\255\255\255\255\
    \045\001\255\255\045\001\045\001\045\001\045\001\045\001\045\001\
    \045\001\045\001\045\001\045\001\045\001\255\255\255\255\045\001\
    \255\255\255\255\255\255\255\255\255\255\221\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\045\001\091\001\255\255\091\001\
    \255\255\045\001\091\001\091\001\091\001\091\001\091\001\091\001\
    \091\001\091\001\091\001\091\001\255\255\255\255\045\001\093\001\
    \093\001\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
    \093\001\045\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\045\001\255\255\255\255\093\001\255\255\255\255\045\001\
    \255\255\255\255\094\001\255\255\094\001\255\255\045\001\094\001\
    \094\001\094\001\094\001\094\001\094\001\094\001\094\001\094\001\
    \094\001\095\001\095\001\095\001\095\001\095\001\095\001\095\001\
    \095\001\095\001\095\001\255\255\093\001\096\001\096\001\096\001\
    \096\001\096\001\096\001\096\001\096\001\096\001\096\001\097\001\
    \097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
    \097\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
    \098\001\098\001\098\001\255\255\105\001\106\001\106\001\106\001\
    \106\001\106\001\106\001\106\001\106\001\106\001\106\001\255\255\
    \255\255\105\001\255\255\255\255\255\255\108\001\106\001\106\001\
    \106\001\106\001\106\001\106\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\108\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\106\001\106\001\
    \106\001\106\001\106\001\106\001\255\255\255\255\105\001\255\255\
    \255\255\255\255\255\255\255\255\105\001\255\255\255\255\255\255\
    \105\001\255\255\255\255\255\255\255\255\255\255\255\255\108\001\
    \105\001\255\255\255\255\045\001\105\001\108\001\105\001\105\001\
    \255\255\108\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\108\001\255\255\255\255\255\255\108\001\255\255\108\001\
    \108\001\109\001\109\001\109\001\109\001\109\001\109\001\109\001\
    \109\001\109\001\109\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\109\001\109\001\109\001\109\001\109\001\109\001\
    \110\001\110\001\110\001\110\001\110\001\110\001\110\001\110\001\
    \110\001\110\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\110\001\110\001\110\001\110\001\110\001\110\001\255\255\
    \255\255\255\255\109\001\109\001\109\001\109\001\109\001\109\001\
    \255\255\255\255\255\255\255\255\255\255\255\255\111\001\111\001\
    \111\001\111\001\111\001\111\001\111\001\111\001\111\001\111\001\
    \255\255\110\001\110\001\110\001\110\001\110\001\110\001\111\001\
    \111\001\111\001\111\001\111\001\111\001\255\255\117\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\111\001\
    \111\001\111\001\111\001\111\001\111\001\117\001\117\001\117\001\
    \117\001\117\001\117\001\117\001\117\001\117\001\117\001\117\001\
    \117\001\117\001\117\001\117\001\117\001\117\001\117\001\117\001\
    \117\001\117\001\117\001\117\001\117\001\117\001\117\001\255\255\
    \255\255\255\255\255\255\117\001\255\255\117\001\117\001\117\001\
    \117\001\117\001\117\001\117\001\117\001\117\001\117\001\117\001\
    \117\001\117\001\117\001\117\001\117\001\117\001\117\001\117\001\
    \117\001\117\001\117\001\117\001\117\001\117\001\117\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\255\255\255\255\255\255\255\255\120\001\255\255\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\117\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    ";
  Lexing.lex_base_code = 
   "";
  Lexing.lex_backtrk_code = 
   "";
  Lexing.lex_default_code = 
   "";
  Lexing.lex_trans_code = 
   "";
  Lexing.lex_check_code = 
   "";
  Lexing.lex_code = 
   "";
}

let rec read_json v lexbuf =
    __ocaml_lex_read_json_rec v lexbuf 0
and __ocaml_lex_read_json_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 188 "read.mll"
                ( `Bool true )
# 821 "read.ml"

  | 1 ->
# 189 "read.mll"
                ( `Bool false )
# 826 "read.ml"

  | 2 ->
# 190 "read.mll"
                ( `Null )
# 831 "read.ml"

  | 3 ->
# 191 "read.mll"
                (
                  #ifdef FLOAT
                    `Float nan
                  #elif defined FLOATLIT
                    `Floatlit "NaN"
                  #endif
                )
# 842 "read.ml"

  | 4 ->
# 198 "read.mll"
                (
                  #ifdef FLOAT
                    `Float infinity
                  #elif defined FLOATLIT
                    `Floatlit "Infinity"
                  #endif
                )
# 853 "read.ml"

  | 5 ->
# 205 "read.mll"
                (
                  #ifdef FLOAT
                    `Float neg_infinity
                  #elif defined FLOATLIT
                    `Floatlit "-Infinity"
                  #endif
                )
# 864 "read.ml"

  | 6 ->
# 212 "read.mll"
                (
                  #ifdef STRING
	            Bi_outbuf.clear v.buf;
		    `String (finish_string v lexbuf)
                  #elif defined STRINGLIT
                    `Stringlit (finish_stringlit v lexbuf)
                  #endif
                )
# 876 "read.ml"

  | 7 ->
# 220 "read.mll"
                         ( make_positive_int v lexbuf )
# 881 "read.ml"

  | 8 ->
# 221 "read.mll"
                         ( make_negative_int v lexbuf )
# 886 "read.ml"

  | 9 ->
# 222 "read.mll"
                (
                  #ifdef FLOAT
                    `Float (float_of_string (lexeme lexbuf))
                  #elif defined FLOATLIT
                    `Floatlit (lexeme lexbuf)
                  #endif
                 )
# 897 "read.ml"

  | 10 ->
# 230 "read.mll"
                 ( let acc = ref [] in
		   try
		     read_space v lexbuf;
		     read_object_end lexbuf;
		     let field_name = read_ident v lexbuf in
		     read_space v lexbuf;
		     read_colon v lexbuf;
		     read_space v lexbuf;
		     acc := (field_name, read_json v lexbuf) :: !acc;
		     while true do
		       read_space v lexbuf;
		       read_object_sep v lexbuf;
		       read_space v lexbuf;
		       let field_name = read_ident v lexbuf in
		       read_space v lexbuf;
		       read_colon v lexbuf;
		       read_space v lexbuf;
		       acc := (field_name, read_json v lexbuf) :: !acc;
		     done;
		     assert false
		   with End_of_object ->
		     `Assoc (List.rev !acc)
		 )
# 924 "read.ml"

  | 11 ->
# 254 "read.mll"
                 ( let acc = ref [] in
		   try
		     read_space v lexbuf;
		     read_array_end lexbuf;
		     acc := read_json v lexbuf :: !acc;
		     while true do
		       read_space v lexbuf;
		       read_array_sep v lexbuf;
		       read_space v lexbuf;
		       acc := read_json v lexbuf :: !acc;
		     done;
		     assert false
		   with End_of_array ->
		     `List (List.rev !acc)
		 )
# 943 "read.ml"

  | 12 ->
# 270 "read.mll"
                 (
                   #ifdef TUPLE
                     let acc = ref [] in
		     try
		       read_space v lexbuf;
		       read_tuple_end lexbuf;
		       acc := read_json v lexbuf :: !acc;
		       while true do
			 read_space v lexbuf;
			 read_tuple_sep v lexbuf;
			 read_space v lexbuf;
			 acc := read_json v lexbuf :: !acc;
		       done;
		       assert false
		     with End_of_tuple ->
		       `Tuple (List.rev !acc)
	           #else
		     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 967 "read.ml"

  | 13 ->
# 291 "read.mll"
                 (
                   #ifdef VARIANT
                     read_space v lexbuf;
                     let cons = read_ident v lexbuf in
		     read_space v lexbuf;
		     `Variant (cons, finish_variant v lexbuf)
                   #else
                     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 981 "read.ml"

  | 14 ->
# 302 "read.mll"
                 ( read_json v lexbuf )
# 986 "read.ml"

  | 15 ->
# 303 "read.mll"
                 ( finish_comment v lexbuf; read_json v lexbuf )
# 991 "read.ml"

  | 16 ->
# 304 "read.mll"
                 ( newline v lexbuf; read_json v lexbuf )
# 996 "read.ml"

  | 17 ->
# 305 "read.mll"
                 ( read_json v lexbuf )
# 1001 "read.ml"

  | 18 ->
# 306 "read.mll"
                 ( custom_error "Unexpected end of input" v lexbuf )
# 1006 "read.ml"

  | 19 ->
# 307 "read.mll"
                 ( long_error "Invalid token" v lexbuf )
# 1011 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_json_rec v lexbuf __ocaml_lex_state

and finish_string v lexbuf =
    __ocaml_lex_finish_string_rec v lexbuf 58
and __ocaml_lex_finish_string_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 311 "read.mll"
                  ( Bi_outbuf.contents v.buf )
# 1022 "read.ml"

  | 1 ->
# 312 "read.mll"
                  ( finish_escaped_char v lexbuf;
		    finish_string v lexbuf )
# 1028 "read.ml"

  | 2 ->
# 314 "read.mll"
                  ( add_lexeme v.buf lexbuf;
		    finish_string v lexbuf )
# 1034 "read.ml"

  | 3 ->
# 316 "read.mll"
                  ( custom_error "Unexpected end of input" v lexbuf )
# 1039 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_finish_string_rec v lexbuf __ocaml_lex_state

and map_string v f lexbuf =
    __ocaml_lex_map_string_rec v f lexbuf 63
and __ocaml_lex_map_string_rec v f lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 319 "read.mll"
                  ( let b = v.buf in
                    f b.Bi_outbuf.o_s 0 b.Bi_outbuf.o_len )
# 1051 "read.ml"

  | 1 ->
# 321 "read.mll"
                  ( finish_escaped_char v lexbuf;
		    map_string v f lexbuf )
# 1057 "read.ml"

  | 2 ->
# 323 "read.mll"
                  ( add_lexeme v.buf lexbuf;
		    map_string v f lexbuf )
# 1063 "read.ml"

  | 3 ->
# 325 "read.mll"
                  ( custom_error "Unexpected end of input" v lexbuf )
# 1068 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_map_string_rec v f lexbuf __ocaml_lex_state

and finish_escaped_char v lexbuf =
    __ocaml_lex_finish_escaped_char_rec v lexbuf 68
and __ocaml_lex_finish_escaped_char_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
let
# 330 "read.mll"
           c
# 1080 "read.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 330 "read.mll"
             ( Bi_outbuf.add_char v.buf c )
# 1084 "read.ml"

  | 1 ->
# 331 "read.mll"
         ( Bi_outbuf.add_char v.buf '\b' )
# 1089 "read.ml"

  | 2 ->
# 332 "read.mll"
         ( Bi_outbuf.add_char v.buf '\012' )
# 1094 "read.ml"

  | 3 ->
# 333 "read.mll"
         ( Bi_outbuf.add_char v.buf '\n' )
# 1099 "read.ml"

  | 4 ->
# 334 "read.mll"
         ( Bi_outbuf.add_char v.buf '\r' )
# 1104 "read.ml"

  | 5 ->
# 335 "read.mll"
         ( Bi_outbuf.add_char v.buf '\t' )
# 1109 "read.ml"

  | 6 ->
let
# 336 "read.mll"
                a
# 1115 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 1)
and
# 336 "read.mll"
                           b
# 1120 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 2)
and
# 336 "read.mll"
                                      c
# 1125 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 3)
and
# 336 "read.mll"
                                                 d
# 1130 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 4) in
# 337 "read.mll"
         ( utf8_of_bytes v.buf (hex a) (hex b) (hex c) (hex d) )
# 1134 "read.ml"

  | 7 ->
# 338 "read.mll"
         ( long_error "Invalid escape sequence" v lexbuf )
# 1139 "read.ml"

  | 8 ->
# 339 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1144 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_finish_escaped_char_rec v lexbuf __ocaml_lex_state

and finish_stringlit v lexbuf =
    __ocaml_lex_finish_stringlit_rec v lexbuf 82
and __ocaml_lex_finish_stringlit_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 345 "read.mll"
         ( let len = lexbuf.lex_curr_pos - lexbuf.lex_start_pos in
	   let s = String.create (len+1) in
	   s.[0] <- '"';
	   String.blit lexbuf.lex_buffer lexbuf.lex_start_pos s 1 len;
	   s
	 )
# 1160 "read.ml"

  | 1 ->
# 351 "read.mll"
         ( long_error "Invalid string literal" v lexbuf )
# 1165 "read.ml"

  | 2 ->
# 352 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1170 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_finish_stringlit_rec v lexbuf __ocaml_lex_state

and finish_variant v lexbuf =
    __ocaml_lex_finish_variant_rec v lexbuf 93
and __ocaml_lex_finish_variant_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 355 "read.mll"
         ( let x = read_json v lexbuf in
	   read_space v lexbuf;
	   read_gt v lexbuf;
	   Some x )
# 1184 "read.ml"

  | 1 ->
# 359 "read.mll"
         ( None )
# 1189 "read.ml"

  | 2 ->
# 360 "read.mll"
         ( long_error "Expected ':' or '>' but found" v lexbuf )
# 1194 "read.ml"

  | 3 ->
# 361 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1199 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_finish_variant_rec v lexbuf __ocaml_lex_state

and read_lt v lexbuf =
    __ocaml_lex_read_lt_rec v lexbuf 98
and __ocaml_lex_read_lt_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 364 "read.mll"
             ( () )
# 1210 "read.ml"

  | 1 ->
# 365 "read.mll"
             ( long_error "Expected '<' but found" v lexbuf )
# 1215 "read.ml"

  | 2 ->
# 366 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1220 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_lt_rec v lexbuf __ocaml_lex_state

and read_gt v lexbuf =
    __ocaml_lex_read_gt_rec v lexbuf 102
and __ocaml_lex_read_gt_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 369 "read.mll"
         ( () )
# 1231 "read.ml"

  | 1 ->
# 370 "read.mll"
         ( long_error "Expected '>' but found" v lexbuf )
# 1236 "read.ml"

  | 2 ->
# 371 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1241 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_gt_rec v lexbuf __ocaml_lex_state

and read_comma v lexbuf =
    __ocaml_lex_read_comma_rec v lexbuf 106
and __ocaml_lex_read_comma_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 374 "read.mll"
         ( () )
# 1252 "read.ml"

  | 1 ->
# 375 "read.mll"
         ( long_error "Expected ',' but found" v lexbuf )
# 1257 "read.ml"

  | 2 ->
# 376 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1262 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_comma_rec v lexbuf __ocaml_lex_state

and start_any_variant v lexbuf =
    __ocaml_lex_start_any_variant_rec v lexbuf 110
and __ocaml_lex_start_any_variant_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 379 "read.mll"
             ( `Edgy_bracket )
# 1273 "read.ml"

  | 1 ->
# 380 "read.mll"
             ( Bi_outbuf.clear v.buf;
	       `Double_quote )
# 1279 "read.ml"

  | 2 ->
# 382 "read.mll"
             ( `Square_bracket )
# 1284 "read.ml"

  | 3 ->
# 383 "read.mll"
             ( long_error "Expected '<', '\"' or '[' but found" v lexbuf )
# 1289 "read.ml"

  | 4 ->
# 384 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1294 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_start_any_variant_rec v lexbuf __ocaml_lex_state

and finish_comment v lexbuf =
    __ocaml_lex_finish_comment_rec v lexbuf 116
and __ocaml_lex_finish_comment_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 387 "read.mll"
         ( () )
# 1305 "read.ml"

  | 1 ->
# 388 "read.mll"
         ( long_error "Unterminated comment" v lexbuf )
# 1310 "read.ml"

  | 2 ->
# 389 "read.mll"
         ( newline v lexbuf; finish_comment v lexbuf )
# 1315 "read.ml"

  | 3 ->
# 390 "read.mll"
         ( finish_comment v lexbuf )
# 1320 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_finish_comment_rec v lexbuf __ocaml_lex_state

and read_eof lexbuf =
    __ocaml_lex_read_eof_rec lexbuf 122
and __ocaml_lex_read_eof_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 398 "read.mll"
              ( true )
# 1331 "read.ml"

  | 1 ->
# 399 "read.mll"
              ( false )
# 1336 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_eof_rec lexbuf __ocaml_lex_state

and read_space v lexbuf =
    __ocaml_lex_read_space_rec v lexbuf 124
and __ocaml_lex_read_space_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 402 "read.mll"
                             ( newline v lexbuf; read_space v lexbuf )
# 1347 "read.ml"

  | 1 ->
# 403 "read.mll"
                             ( finish_comment v lexbuf; read_space v lexbuf )
# 1352 "read.ml"

  | 2 ->
# 404 "read.mll"
                             ( newline v lexbuf; read_space v lexbuf )
# 1357 "read.ml"

  | 3 ->
# 405 "read.mll"
                             ( read_space v lexbuf )
# 1362 "read.ml"

  | 4 ->
# 406 "read.mll"
                             ( () )
# 1367 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_space_rec v lexbuf __ocaml_lex_state

and read_null v lexbuf =
    __ocaml_lex_read_null_rec v lexbuf 131
and __ocaml_lex_read_null_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 409 "read.mll"
              ( () )
# 1378 "read.ml"

  | 1 ->
# 410 "read.mll"
              ( long_error "Expected 'null' but found" v lexbuf )
# 1383 "read.ml"

  | 2 ->
# 411 "read.mll"
              ( custom_error "Unexpected end of input" v lexbuf )
# 1388 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_null_rec v lexbuf __ocaml_lex_state

and read_null_if_possible v lexbuf =
    __ocaml_lex_read_null_if_possible_rec v lexbuf 138
and __ocaml_lex_read_null_if_possible_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 414 "read.mll"
              ( true )
# 1399 "read.ml"

  | 1 ->
# 415 "read.mll"
              ( false )
# 1404 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_null_if_possible_rec v lexbuf __ocaml_lex_state

and read_bool v lexbuf =
    __ocaml_lex_read_bool_rec v lexbuf 143
and __ocaml_lex_read_bool_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 418 "read.mll"
              ( true )
# 1415 "read.ml"

  | 1 ->
# 419 "read.mll"
              ( false )
# 1420 "read.ml"

  | 2 ->
# 420 "read.mll"
              ( long_error "Expected 'true' or 'false' but found" v lexbuf )
# 1425 "read.ml"

  | 3 ->
# 421 "read.mll"
              ( custom_error "Unexpected end of input" v lexbuf )
# 1430 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_bool_rec v lexbuf __ocaml_lex_state

and read_int v lexbuf =
    __ocaml_lex_read_int_rec v lexbuf 155
and __ocaml_lex_read_int_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 424 "read.mll"
                         ( try extract_positive_int lexbuf
			   with Int_overflow ->
			     lexer_error "Int overflow" v lexbuf )
# 1443 "read.ml"

  | 1 ->
# 427 "read.mll"
                         ( try extract_negative_int lexbuf
			   with Int_overflow ->
			     lexer_error "Int overflow" v lexbuf )
# 1450 "read.ml"

  | 2 ->
# 430 "read.mll"
                         ( (* Support for double-quoted "ints" *)
                           Bi_outbuf.clear v.buf;
                           let s = finish_string v lexbuf in
                           try
                             (* Any OCaml-compliant int will pass,
                                including hexadecimal and octal notations,
                                and embedded underscores *)
                             int_of_string s
                           with _ ->
                             custom_error
                               "Expected an integer but found a string that \
                                doesn't even represent an integer"
                               v lexbuf
                         )
# 1468 "read.ml"

  | 3 ->
# 444 "read.mll"
                         ( long_error "Expected integer but found" v lexbuf )
# 1473 "read.ml"

  | 4 ->
# 445 "read.mll"
                         ( custom_error "Unexpected end of input" v lexbuf )
# 1478 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_int_rec v lexbuf __ocaml_lex_state

and read_int32 v lexbuf =
    __ocaml_lex_read_int32_rec v lexbuf 164
and __ocaml_lex_read_int32_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 448 "read.mll"
                         ( try Int32.of_string (Lexing.lexeme lexbuf)
			   with _ ->
			     lexer_error "Int32 overflow" v lexbuf )
# 1491 "read.ml"

  | 1 ->
# 451 "read.mll"
                         ( (* Support for double-quoted "ints" *)
                           Bi_outbuf.clear v.buf;
                           let s = finish_string v lexbuf in
                           try
                             (* Any OCaml-compliant int will pass,
                                including hexadecimal and octal notations,
                                and embedded underscores *)
                             Int32.of_string s
                           with _ ->
                             custom_error
                               "Expected an int32 but found a string that \
                                doesn't even represent an integer"
                               v lexbuf
                         )
# 1509 "read.ml"

  | 2 ->
# 465 "read.mll"
                         ( long_error "Expected int32 but found" v lexbuf )
# 1514 "read.ml"

  | 3 ->
# 466 "read.mll"
                         ( custom_error "Unexpected end of input" v lexbuf )
# 1519 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_int32_rec v lexbuf __ocaml_lex_state

and read_int64 v lexbuf =
    __ocaml_lex_read_int64_rec v lexbuf 171
and __ocaml_lex_read_int64_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 469 "read.mll"
                         ( try Int64.of_string (Lexing.lexeme lexbuf)
			   with _ ->
			     lexer_error "Int32 overflow" v lexbuf )
# 1532 "read.ml"

  | 1 ->
# 472 "read.mll"
                         ( (* Support for double-quoted "ints" *)
                           Bi_outbuf.clear v.buf;
                           let s = finish_string v lexbuf in
                           try
                             (* Any OCaml-compliant int will pass,
                                including hexadecimal and octal notations,
                                and embedded underscores *)
                             Int64.of_string s
                           with _ ->
                             custom_error
                               "Expected an int64 but found a string that \
                                doesn't even represent an integer"
                               v lexbuf
                         )
# 1550 "read.ml"

  | 2 ->
# 486 "read.mll"
                         ( long_error "Expected int64 but found" v lexbuf )
# 1555 "read.ml"

  | 3 ->
# 487 "read.mll"
                         ( custom_error "Unexpected end of input" v lexbuf )
# 1560 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_int64_rec v lexbuf __ocaml_lex_state

and read_number v lexbuf =
    __ocaml_lex_read_number_rec v lexbuf 178
and __ocaml_lex_read_number_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 490 "read.mll"
                ( nan )
# 1571 "read.ml"

  | 1 ->
# 491 "read.mll"
                ( infinity )
# 1576 "read.ml"

  | 2 ->
# 492 "read.mll"
                ( neg_infinity )
# 1581 "read.ml"

  | 3 ->
# 493 "read.mll"
                ( float_of_string (lexeme lexbuf) )
# 1586 "read.ml"

  | 4 ->
# 494 "read.mll"
                ( Bi_outbuf.clear v.buf;
	          let s = finish_string v lexbuf in
                  try
                    (* Any OCaml-compliant float will pass,
                       including hexadecimal and octal notations,
                       and embedded underscores. *)
                    float_of_string s
                  with _ ->
                    match s with
                        "NaN" -> nan
                      | "Infinity" -> infinity
                      | "-Infinity" -> neg_infinity
                      | _ ->
                          custom_error
                            "Expected a number but found a string that \
                             doesn't even represent a number"
                            v lexbuf
                )
# 1608 "read.ml"

  | 5 ->
# 512 "read.mll"
                ( long_error "Expected number but found" v lexbuf )
# 1613 "read.ml"

  | 6 ->
# 513 "read.mll"
                ( custom_error "Unexpected end of input" v lexbuf )
# 1618 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_number_rec v lexbuf __ocaml_lex_state

and read_string v lexbuf =
    __ocaml_lex_read_string_rec v lexbuf 212
and __ocaml_lex_read_string_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 516 "read.mll"
             ( Bi_outbuf.clear v.buf;
	       finish_string v lexbuf )
# 1630 "read.ml"

  | 1 ->
# 518 "read.mll"
             ( long_error "Expected '\"' but found" v lexbuf )
# 1635 "read.ml"

  | 2 ->
# 519 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1640 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_string_rec v lexbuf __ocaml_lex_state

and read_ident v lexbuf =
    __ocaml_lex_read_ident_rec v lexbuf 216
and __ocaml_lex_read_ident_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 522 "read.mll"
             ( Bi_outbuf.clear v.buf;
	       finish_string v lexbuf )
# 1652 "read.ml"

  | 1 ->
let
# 524 "read.mll"
             s
# 1658 "read.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 525 "read.mll"
             ( s )
# 1662 "read.ml"

  | 2 ->
# 526 "read.mll"
             ( long_error "Expected string or identifier but found" v lexbuf )
# 1667 "read.ml"

  | 3 ->
# 527 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1672 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_ident_rec v lexbuf __ocaml_lex_state

and map_ident v f lexbuf =
    __ocaml_lex_map_ident_rec v f lexbuf 221
and __ocaml_lex_map_ident_rec v f lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 530 "read.mll"
             ( Bi_outbuf.clear v.buf;
	       map_string v f lexbuf )
# 1684 "read.ml"

  | 1 ->
# 533 "read.mll"
             ( map_lexeme f lexbuf )
# 1689 "read.ml"

  | 2 ->
# 534 "read.mll"
             ( long_error "Expected string or identifier but found" v lexbuf )
# 1694 "read.ml"

  | 3 ->
# 535 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1699 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_map_ident_rec v f lexbuf __ocaml_lex_state

and read_sequence read_cell init_acc v lexbuf =
    __ocaml_lex_read_sequence_rec read_cell init_acc v lexbuf 226
and __ocaml_lex_read_sequence_rec read_cell init_acc v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 538 "read.mll"
             ( let acc = ref init_acc in
	       try
		 read_space v lexbuf;
		 read_array_end lexbuf;
		 acc := read_cell !acc v lexbuf;
		 while true do
		   read_space v lexbuf;
		   read_array_sep v lexbuf;
		   read_space v lexbuf;
		   acc := read_cell !acc v lexbuf;
		 done;
		 assert false
	       with End_of_array ->
		 !acc
	     )
# 1724 "read.ml"

  | 1 ->
# 553 "read.mll"
             ( long_error "Expected '[' but found" v lexbuf )
# 1729 "read.ml"

  | 2 ->
# 554 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1734 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_sequence_rec read_cell init_acc v lexbuf __ocaml_lex_state

and read_list_rev read_cell v lexbuf =
    __ocaml_lex_read_list_rev_rec read_cell v lexbuf 230
and __ocaml_lex_read_list_rev_rec read_cell v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 557 "read.mll"
             ( let acc = ref [] in
	       try
		 read_space v lexbuf;
		 read_array_end lexbuf;
		 acc := read_cell v lexbuf :: !acc;
		 while true do
		   read_space v lexbuf;
		   read_array_sep v lexbuf;
		   read_space v lexbuf;
		   acc := read_cell v lexbuf :: !acc;
		 done;
		 assert false
	       with End_of_array ->
		 !acc
	     )
# 1759 "read.ml"

  | 1 ->
# 572 "read.mll"
             ( long_error "Expected '[' but found" v lexbuf )
# 1764 "read.ml"

  | 2 ->
# 573 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1769 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_list_rev_rec read_cell v lexbuf __ocaml_lex_state

and read_array_end lexbuf =
    __ocaml_lex_read_array_end_rec lexbuf 234
and __ocaml_lex_read_array_end_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 576 "read.mll"
             ( raise End_of_array )
# 1780 "read.ml"

  | 1 ->
# 577 "read.mll"
             ( () )
# 1785 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_array_end_rec lexbuf __ocaml_lex_state

and read_array_sep v lexbuf =
    __ocaml_lex_read_array_sep_rec v lexbuf 236
and __ocaml_lex_read_array_sep_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 580 "read.mll"
             ( () )
# 1796 "read.ml"

  | 1 ->
# 581 "read.mll"
             ( raise End_of_array )
# 1801 "read.ml"

  | 2 ->
# 582 "read.mll"
             ( long_error "Expected ',' or ']' but found" v lexbuf )
# 1806 "read.ml"

  | 3 ->
# 583 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1811 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_array_sep_rec v lexbuf __ocaml_lex_state

and read_tuple read_cell init_acc v lexbuf =
    __ocaml_lex_read_tuple_rec read_cell init_acc v lexbuf 241
and __ocaml_lex_read_tuple_rec read_cell init_acc v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 587 "read.mll"
                 (
                   #ifdef TUPLE
                     let pos = ref 0 in
                     let acc = ref init_acc in
		     try
		       read_space v lexbuf;
		       read_tuple_end lexbuf;
		       acc := read_cell !pos !acc v lexbuf;
		       incr pos;
		       while true do
			 read_space v lexbuf;
			 read_tuple_sep v lexbuf;
			 read_space v lexbuf;
			 acc := read_cell !pos !acc v lexbuf;
			 incr pos;
		       done;
		       assert false
		     with End_of_tuple ->
		       !acc
	           #else
		     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 1844 "read.ml"

  | 1 ->
# 610 "read.mll"
             ( long_error "Expected ')' but found" v lexbuf )
# 1849 "read.ml"

  | 2 ->
# 611 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1854 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_tuple_rec read_cell init_acc v lexbuf __ocaml_lex_state

and read_tuple_end lexbuf =
    __ocaml_lex_read_tuple_end_rec lexbuf 245
and __ocaml_lex_read_tuple_end_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 614 "read.mll"
             ( raise End_of_tuple )
# 1865 "read.ml"

  | 1 ->
# 615 "read.mll"
             ( () )
# 1870 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_tuple_end_rec lexbuf __ocaml_lex_state

and read_tuple_end2 v std lexbuf =
    __ocaml_lex_read_tuple_end2_rec v std lexbuf 247
and __ocaml_lex_read_tuple_end2_rec v std lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 618 "read.mll"
             ( if std then 
                 long_error "Expected ')' or '' but found" v lexbuf
               else
                 raise End_of_tuple )
# 1884 "read.ml"

  | 1 ->
# 622 "read.mll"
             ( if std then 
                 raise End_of_tuple
               else
                 long_error "Expected ']' or '' but found" v lexbuf )
# 1892 "read.ml"

  | 2 ->
# 626 "read.mll"
             ( () )
# 1897 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_tuple_end2_rec v std lexbuf __ocaml_lex_state

and read_tuple_sep v lexbuf =
    __ocaml_lex_read_tuple_sep_rec v lexbuf 250
and __ocaml_lex_read_tuple_sep_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 629 "read.mll"
             ( () )
# 1908 "read.ml"

  | 1 ->
# 630 "read.mll"
             ( raise End_of_tuple )
# 1913 "read.ml"

  | 2 ->
# 631 "read.mll"
             ( long_error "Expected ',' or ')' but found" v lexbuf )
# 1918 "read.ml"

  | 3 ->
# 632 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1923 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_tuple_sep_rec v lexbuf __ocaml_lex_state

and read_tuple_sep2 v std lexbuf =
    __ocaml_lex_read_tuple_sep2_rec v std lexbuf 255
and __ocaml_lex_read_tuple_sep2_rec v std lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 635 "read.mll"
             ( () )
# 1934 "read.ml"

  | 1 ->
# 636 "read.mll"
             ( if std then 
                 long_error "Expected ',' or ']' but found" v lexbuf
               else
                 raise End_of_tuple )
# 1942 "read.ml"

  | 2 ->
# 640 "read.mll"
             ( if std then 
                 raise End_of_tuple
               else
                 long_error "Expected ',' or ')' but found" v lexbuf )
# 1950 "read.ml"

  | 3 ->
# 644 "read.mll"
             ( long_error "Expected ',' or ')' but found" v lexbuf )
# 1955 "read.ml"

  | 4 ->
# 645 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1960 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_tuple_sep2_rec v std lexbuf __ocaml_lex_state

and read_fields read_field init_acc v lexbuf =
    __ocaml_lex_read_fields_rec read_field init_acc v lexbuf 261
and __ocaml_lex_read_fields_rec read_field init_acc v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 648 "read.mll"
             ( let acc = ref init_acc in
	       try
		 read_space v lexbuf;
		 read_object_end lexbuf;
		 let field_name = read_ident v lexbuf in
		 read_space v lexbuf;
		 read_colon v lexbuf;
		 read_space v lexbuf;
		 acc := read_field !acc field_name v lexbuf;
		 while true do
		   read_space v lexbuf;
		   read_object_sep v lexbuf;
		   read_space v lexbuf;
		   let field_name = read_ident v lexbuf in
		   read_space v lexbuf;
		   read_colon v lexbuf;
		   read_space v lexbuf;
		   acc := read_field !acc field_name v lexbuf;
		 done;
		 assert false
	       with End_of_object ->
		 !acc
	     )
# 1993 "read.ml"

  | 1 ->
# 671 "read.mll"
             ( long_error "Expected '{' but found" v lexbuf )
# 1998 "read.ml"

  | 2 ->
# 672 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2003 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_fields_rec read_field init_acc v lexbuf __ocaml_lex_state

and read_lcurl v lexbuf =
    __ocaml_lex_read_lcurl_rec v lexbuf 265
and __ocaml_lex_read_lcurl_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 675 "read.mll"
             ( () )
# 2014 "read.ml"

  | 1 ->
# 676 "read.mll"
             ( long_error "Expected '{' but found" v lexbuf )
# 2019 "read.ml"

  | 2 ->
# 677 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2024 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_lcurl_rec v lexbuf __ocaml_lex_state

and read_object_end lexbuf =
    __ocaml_lex_read_object_end_rec lexbuf 269
and __ocaml_lex_read_object_end_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 680 "read.mll"
             ( raise End_of_object )
# 2035 "read.ml"

  | 1 ->
# 681 "read.mll"
             ( () )
# 2040 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_object_end_rec lexbuf __ocaml_lex_state

and read_object_sep v lexbuf =
    __ocaml_lex_read_object_sep_rec v lexbuf 271
and __ocaml_lex_read_object_sep_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 684 "read.mll"
             ( () )
# 2051 "read.ml"

  | 1 ->
# 685 "read.mll"
             ( raise End_of_object )
# 2056 "read.ml"

  | 2 ->
# 686 "read.mll"
             ( long_error "Expected ',' or '}' but found" v lexbuf )
# 2061 "read.ml"

  | 3 ->
# 687 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2066 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_object_sep_rec v lexbuf __ocaml_lex_state

and read_colon v lexbuf =
    __ocaml_lex_read_colon_rec v lexbuf 276
and __ocaml_lex_read_colon_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 690 "read.mll"
             ( () )
# 2077 "read.ml"

  | 1 ->
# 691 "read.mll"
             ( long_error "Expected ':' but found" v lexbuf )
# 2082 "read.ml"

  | 2 ->
# 692 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2087 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_colon_rec v lexbuf __ocaml_lex_state

and start_any_tuple v lexbuf =
    __ocaml_lex_start_any_tuple_rec v lexbuf 280
and __ocaml_lex_start_any_tuple_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 695 "read.mll"
             ( false )
# 2098 "read.ml"

  | 1 ->
# 696 "read.mll"
             ( true )
# 2103 "read.ml"

  | 2 ->
# 697 "read.mll"
             ( long_error "Expected '(' or '[' but found" v lexbuf )
# 2108 "read.ml"

  | 3 ->
# 698 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2113 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_start_any_tuple_rec v lexbuf __ocaml_lex_state

and read_lpar v lexbuf =
    __ocaml_lex_read_lpar_rec v lexbuf 285
and __ocaml_lex_read_lpar_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 701 "read.mll"
             ( () )
# 2124 "read.ml"

  | 1 ->
# 702 "read.mll"
             ( long_error "Expected '(' but found" v lexbuf )
# 2129 "read.ml"

  | 2 ->
# 703 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2134 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_lpar_rec v lexbuf __ocaml_lex_state

and read_rpar v lexbuf =
    __ocaml_lex_read_rpar_rec v lexbuf 289
and __ocaml_lex_read_rpar_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 706 "read.mll"
             ( () )
# 2145 "read.ml"

  | 1 ->
# 707 "read.mll"
             ( long_error "Expected ')' but found" v lexbuf )
# 2150 "read.ml"

  | 2 ->
# 708 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2155 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_rpar_rec v lexbuf __ocaml_lex_state

and read_lbr v lexbuf =
    __ocaml_lex_read_lbr_rec v lexbuf 293
and __ocaml_lex_read_lbr_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 711 "read.mll"
             ( () )
# 2166 "read.ml"

  | 1 ->
# 712 "read.mll"
             ( long_error "Expected '[' but found" v lexbuf )
# 2171 "read.ml"

  | 2 ->
# 713 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2176 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_lbr_rec v lexbuf __ocaml_lex_state

and read_rbr v lexbuf =
    __ocaml_lex_read_rbr_rec v lexbuf 297
and __ocaml_lex_read_rbr_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 716 "read.mll"
             ( () )
# 2187 "read.ml"

  | 1 ->
# 717 "read.mll"
             ( long_error "Expected ']' but found" v lexbuf )
# 2192 "read.ml"

  | 2 ->
# 718 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2197 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_read_rbr_rec v lexbuf __ocaml_lex_state

and skip_json v lexbuf =
    __ocaml_lex_skip_json_rec v lexbuf 301
and __ocaml_lex_skip_json_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 724 "read.mll"
                ( () )
# 2208 "read.ml"

  | 1 ->
# 725 "read.mll"
                ( () )
# 2213 "read.ml"

  | 2 ->
# 726 "read.mll"
                ( () )
# 2218 "read.ml"

  | 3 ->
# 727 "read.mll"
                ( () )
# 2223 "read.ml"

  | 4 ->
# 728 "read.mll"
                ( () )
# 2228 "read.ml"

  | 5 ->
# 729 "read.mll"
                ( () )
# 2233 "read.ml"

  | 6 ->
# 730 "read.mll"
                ( finish_skip_stringlit v lexbuf )
# 2238 "read.ml"

  | 7 ->
# 731 "read.mll"
                          ( () )
# 2243 "read.ml"

  | 8 ->
# 732 "read.mll"
                ( () )
# 2248 "read.ml"

  | 9 ->
# 734 "read.mll"
                 ( try
		     read_space v lexbuf;
		     read_object_end lexbuf;
		     skip_ident v lexbuf;
		     read_space v lexbuf;
		     read_colon v lexbuf;
		     read_space v lexbuf;
		     skip_json v lexbuf;
		     while true do
		       read_space v lexbuf;
		       read_object_sep v lexbuf;
		       read_space v lexbuf;
		       skip_ident v lexbuf;
		       read_space v lexbuf;
		       read_colon v lexbuf;
		       read_space v lexbuf;
		       skip_json v lexbuf;
		     done;
		     assert false
		   with End_of_object ->
		     ()
		 )
# 2274 "read.ml"

  | 10 ->
# 757 "read.mll"
                 ( try
		     read_space v lexbuf;
		     read_array_end lexbuf;
		     skip_json v lexbuf;
		     while true do
		       read_space v lexbuf;
		       read_array_sep v lexbuf;
		       read_space v lexbuf;
		       skip_json v lexbuf;
		     done;
		     assert false
		   with End_of_array ->
		     ()
		 )
# 2292 "read.ml"

  | 11 ->
# 772 "read.mll"
                 (
                   #ifdef TUPLE
                     try
		       read_space v lexbuf;
		       read_tuple_end lexbuf;
		       skip_json v lexbuf;
		       while true do
			 read_space v lexbuf;
			 read_tuple_sep v lexbuf;
			 read_space v lexbuf;
			 skip_json v lexbuf;
		       done;
		       assert false
		     with End_of_tuple ->
		       ()
	           #else
		     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 2315 "read.ml"

  | 12 ->
# 792 "read.mll"
                 (
                   #ifdef VARIANT
                     read_space v lexbuf;
                     skip_ident v lexbuf;
		     read_space v lexbuf;
		     finish_skip_variant v lexbuf
                   #else
                     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 2329 "read.ml"

  | 13 ->
# 803 "read.mll"
                 ( skip_json v lexbuf )
# 2334 "read.ml"

  | 14 ->
# 804 "read.mll"
                 ( finish_comment v lexbuf; skip_json v lexbuf )
# 2339 "read.ml"

  | 15 ->
# 805 "read.mll"
                 ( newline v lexbuf; skip_json v lexbuf )
# 2344 "read.ml"

  | 16 ->
# 806 "read.mll"
                 ( skip_json v lexbuf )
# 2349 "read.ml"

  | 17 ->
# 807 "read.mll"
                 ( custom_error "Unexpected end of input" v lexbuf )
# 2354 "read.ml"

  | 18 ->
# 808 "read.mll"
                 ( long_error "Invalid token" v lexbuf )
# 2359 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_skip_json_rec v lexbuf __ocaml_lex_state

and finish_skip_stringlit v lexbuf =
    __ocaml_lex_finish_skip_stringlit_rec v lexbuf 357
and __ocaml_lex_finish_skip_stringlit_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 814 "read.mll"
         ( () )
# 2370 "read.ml"

  | 1 ->
# 815 "read.mll"
         ( long_error "Invalid string literal" v lexbuf )
# 2375 "read.ml"

  | 2 ->
# 816 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 2380 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_finish_skip_stringlit_rec v lexbuf __ocaml_lex_state

and finish_skip_variant v lexbuf =
    __ocaml_lex_finish_skip_variant_rec v lexbuf 368
and __ocaml_lex_finish_skip_variant_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 819 "read.mll"
         ( skip_json v lexbuf;
	   read_space v lexbuf;
	   read_gt v lexbuf )
# 2393 "read.ml"

  | 1 ->
# 822 "read.mll"
         ( () )
# 2398 "read.ml"

  | 2 ->
# 823 "read.mll"
         ( long_error "Expected ':' or '>' but found" v lexbuf )
# 2403 "read.ml"

  | 3 ->
# 824 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 2408 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_finish_skip_variant_rec v lexbuf __ocaml_lex_state

and skip_ident v lexbuf =
    __ocaml_lex_skip_ident_rec v lexbuf 373
and __ocaml_lex_skip_ident_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 827 "read.mll"
             ( finish_skip_stringlit v lexbuf )
# 2419 "read.ml"

  | 1 ->
# 828 "read.mll"
             ( () )
# 2424 "read.ml"

  | 2 ->
# 829 "read.mll"
             ( long_error "Expected string or identifier but found" v lexbuf )
# 2429 "read.ml"

  | 3 ->
# 830 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2434 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_skip_ident_rec v lexbuf __ocaml_lex_state

and junk lexbuf =
    __ocaml_lex_junk_rec lexbuf 378
and __ocaml_lex_junk_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 833 "read.mll"
             ( Lexing.lexeme lexbuf )
# 2445 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_junk_rec lexbuf __ocaml_lex_state

;;

# 835 "read.mll"
 
  let _ = (read_json : lexer_state -> Lexing.lexbuf -> json)

  let () =
    read_junk := junk

  let read_int8 v lexbuf =
    let n = read_int v lexbuf in
    if n < 0 || n > 255 then
      lexer_error "Int8 overflow" v lexbuf
    else
      char_of_int n

  let read_list read_cell v lexbuf =
    List.rev (read_list_rev read_cell v lexbuf)

  let array_of_rev_list l =
    match l with
	[] -> [| |]
      | x :: tl ->
	  let len = List.length l in
	  let a = Array.make len x in
	  let r = ref tl in
	  for i = len - 2 downto 0 do
	    a.(i) <- List.hd !r;
	    r := List.tl !r
	  done;
	  a

  let read_array read_cell v lexbuf =
    let l = read_list_rev read_cell v lexbuf in
    array_of_rev_list l

  let finish v lexbuf =
    read_space v lexbuf;
    if not (read_eof lexbuf) then
      long_error "Junk after end of JSON value:" v lexbuf

  let init_lexer = init_lexer

  let from_lexbuf v ?(stream = false) lexbuf =
    read_space v lexbuf;

    let x =
      if read_eof lexbuf then
	raise End_of_input
      else
	read_json v lexbuf
    in

    if not stream then
      finish v lexbuf;

    x


  let from_string ?buf ?fname ?lnum s =
    try
      let lexbuf = Lexing.from_string s in
      let v = init_lexer ?buf ?fname ?lnum () in
      from_lexbuf v lexbuf
    with End_of_input ->
      json_error "Blank input data"

  let from_channel ?buf ?fname ?lnum ic =
    try
      let lexbuf = Lexing.from_channel ic in
      let v = init_lexer ?buf ?fname ?lnum () in
      from_lexbuf v lexbuf
    with End_of_input ->
      json_error "Blank input data"

  let from_file ?buf ?fname ?lnum file =
    let ic = open_in file in
    try
      let x = from_channel ?buf ?fname ?lnum ic in
      close_in ic;
      x
    with e ->
      close_in_noerr ic;
      raise e

  let stream_from_lexbuf v ?(fin = fun () -> ()) lexbuf =
    let stream = Some true in
    let f i =
      try Some (from_lexbuf v ?stream lexbuf)
      with
	  End_of_input ->
	    fin ();
	    None
	| e ->
	    (try fin () with _ -> ());
	    raise e
    in
    Stream.from f

  let stream_from_string ?buf ?fname ?lnum s =
    let v = init_lexer ?buf ?fname ?lnum () in
    stream_from_lexbuf v (Lexing.from_string s)

  let stream_from_channel ?buf ?fin ?fname ?lnum ic =
    let lexbuf = Lexing.from_channel ic in
    let v = init_lexer ?buf ?fname ?lnum () in
    stream_from_lexbuf v ?fin lexbuf

  let stream_from_file ?buf ?fname ?lnum file =
    let ic = open_in file in
    let fin () = close_in ic in
    let fname =
      match fname with
	  None -> Some file
	| x -> x
    in
    let lexbuf = Lexing.from_channel ic in
    let v = init_lexer ?buf ?fname ?lnum () in
    stream_from_lexbuf v ~fin lexbuf

  type json_line = [ `Json of json | `Exn of exn ]

  let linestream_from_channel
      ?buf ?(fin = fun () -> ()) ?fname ?lnum:(lnum0 = 1) ic =
    let buf =
      match buf with
	  None -> Some (Bi_outbuf.create 256)
	| Some _ -> buf
    in
    let f i =
      try 
	let line = input_line ic in
	let lnum = lnum0 + i in
	Some (`Json (from_string ?buf ?fname ~lnum line))
      with
	  End_of_file -> fin (); None
	| e -> Some (`Exn e)
    in
    Stream.from f

  let linestream_from_file ?buf ?fname ?lnum file =
    let ic = open_in file in
    let fin () = close_in ic in
    let fname =
      match fname with
	  None -> Some file
	| x -> x
    in
    linestream_from_channel ?buf ~fin ?fname ?lnum ic

  let prettify ?std s =
    pretty_to_string ?std (from_string s)

  let compact ?std s =
    to_string (from_string s)

# 2605 "read.ml"
